@@ -1,5 +1,5 @@
 from django.contrib.auth.models import User
-from django.test import TestCase
+
 import factory
 
 from .models import Profile
@@ -12,6 +12,16 @@ class UserFactory(factory.Factory):
     username = factory.Sequence(lambda n: 'user-{0}'.format(n).lower())
     email = factory.LazyAttribute(lambda a: '{0}@example.com'.format(a.username).lower())
 
+    @classmethod
+    def _prepare(cls, create, **kwargs):
+        password = kwargs.pop('password', 'password')
+        user = super(UserFactory, cls)._prepare(create=False, **kwargs)
+        user.set_password(password)
+        user.raw_password = password
+        if create:
+            user.save()
+        return user
+
 
 class ProfileFactory(UserFactory):
     FACTORY_FOR = Profile
